@@ -6,6 +6,8 @@ import schedule
 from fastapi import FastAPI
 from loguru import logger as base_logger
 
+
+from .otel import create_tracer, instrument_app
 from .intercept_std_logging import intercept_std_logging
 from .loki_transport import LokiTransport
 from .request_response import apply_middleware
@@ -29,16 +31,15 @@ def attach_context(record):
     record["message"] = logObj
 
 
-def create_logger(console: bool = False, loki=None):
+def create_logger(service_name, console: bool = False, loki=None):
     logger = base_logger.patch(attach_context).opt(depth=1)
     logger.remove()
-
+    logger.level("METRICS", no=1, color="<blue>")
     if console:
         logger.add(sys.stdout, level="INFO")
     if loki:
-        loki_transport = LokiTransport(loki_options=loki)
-        logger.add(loki_transport)
-
+        loki_transport = LokiTransport(loki_options=loki, service_name=service_name)
+        logger.add(loki_transport, level="METRICS")
     return WrapLogger(logger)
 
 
@@ -51,11 +52,15 @@ def run_scheduler():
     create_task(periodic())
 
 
-def logging(app: FastAPI, console: bool = False, loki=None):
-    logger = create_logger(console, loki)
+def logging(app: FastAPI, service_name, console: bool = False, loki=None, tempo=None):
+
+    logger = create_logger(service_name, console, loki)
     set_logger(logger)
     app.logger = logger
     apply_middleware(app)
     run_samplers()
     run_scheduler()
     intercept_std_logging()
+    if tempo is not None:
+        instrument_app(app)
+        create_tracer(service_name, tempo)
